@@ -98,6 +98,14 @@ int Highs_passLp(
     double* avalue  //!< array of length [numnz] with value of matrix entries
 );
 
+/*
+ * @brief
+ */
+int Highs_setHighsBoolOptionValue(void* highs,  //!< HiGHS object reference
+                                  const char* option,  //!< name of the option
+                                  const int value      //!< new value of option
+);
+
 /*
  * @brief
  */
@@ -130,6 +138,14 @@ int Highs_setHighsOptionValue(void* highs,         //!< HiGHS object reference
                               const char* value    //!< new value of option
 );
 
+/*
+ * @brief
+ */
+int Highs_getHighsBoolOptionValue(void* highs,  //!< HiGHS object reference
+                                  const char* option,  //!< name of the option
+                                  int* value           //!< value of option
+);
+
 /*
  * @brief
  */
@@ -146,6 +162,15 @@ int Highs_getHighsDoubleOptionValue(void* highs,  //!< HiGHS object reference
                                     double* value        //!< value of option
 );
 
+/*
+ * @brief
+ */
+int Highs_getHighsStringOptionValue(
+    void* highs,         //!< HiGHS object reference
+    const char* option,  //!< name of the option
+    char* value  //!< pointer to allocated memory to store value of option
+);
+
 /*
  * @brief
  */
