@@ -18,7 +18,8 @@
 #include "lp_data/HConst.h"
 #include "lp_data/HighsLp.h"
 
-HighsStatus solveLpIpx(const HighsLp& lp, const HighsOptions& options,
+HighsStatus solveLpIpx(const HighsOptions& options, HighsTimer& timer,
+                       const HighsLp& lp, bool& imprecise_solution,
                        HighsBasis& highs_basis, HighsSolution& highs_solution,
                        HighsModelStatus& unscaled_model_status,
                        HighsSolutionParams& unscaled_solution_params) {
